summaryrefslogtreecommitdiffstats
path: root/content
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-11 22:37:45 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-11 22:37:45 +0000
commit579e319b672d1e703249fa9f236c6b9dbb7909b5 (patch)
treed3823bf4be2c4180bd7f174405ecece4a62cc78a /content
parent7f66520ba5dd150bbdbaad746539a4206d483dc1 (diff)
downloadchromium_src-579e319b672d1e703249fa9f236c6b9dbb7909b5.zip
chromium_src-579e319b672d1e703249fa9f236c6b9dbb7909b5.tar.gz
chromium_src-579e319b672d1e703249fa9f236c6b9dbb7909b5.tar.bz2
Options: Remove the GTK and Views native options code.
BUG=75320 TEST=none Review URL: http://codereview.chromium.org/6670011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@77878 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content')
-rw-r--r--content/browser/tab_contents/tab_contents_delegate.cc2
-rw-r--r--content/browser/tab_contents/tab_contents_delegate.h4
2 files changed, 3 insertions, 3 deletions
diff --git a/content/browser/tab_contents/tab_contents_delegate.cc b/content/browser/tab_contents/tab_contents_delegate.cc
index 0d099cb..dc316fb 100644
--- a/content/browser/tab_contents/tab_contents_delegate.cc
+++ b/content/browser/tab_contents/tab_contents_delegate.cc
@@ -171,7 +171,7 @@ void TabContentsDelegate::ShowRepostFormWarningDialog(
TabContents* tab_contents) {
}
-void TabContentsDelegate::ShowContentSettingsWindow(
+void TabContentsDelegate::ShowContentSettingsPage(
ContentSettingsType content_type) {
}
diff --git a/content/browser/tab_contents/tab_contents_delegate.h b/content/browser/tab_contents/tab_contents_delegate.h
index 6264575..a079198 100644
--- a/content/browser/tab_contents/tab_contents_delegate.h
+++ b/content/browser/tab_contents/tab_contents_delegate.h
@@ -269,8 +269,8 @@ class TabContentsDelegate : public AutomationResourceRoutingDelegate {
// Shows the repost form confirmation dialog box.
virtual void ShowRepostFormWarningDialog(TabContents* tab_contents);
- // Shows the Content Settings dialog for a given content type.
- virtual void ShowContentSettingsWindow(ContentSettingsType content_type);
+ // Shows the Content Settings page for a given content type.
+ virtual void ShowContentSettingsPage(ContentSettingsType content_type);
// Shows the cookies collected in the tab contents.
virtual void ShowCollectedCookiesDialog(TabContents* tab_contents);